AcquiredLooper

Struct AcquiredLooper 

pub struct AcquiredLooper { /* private fields */ }
RAII acquired looper wrapper.

This prevents the object from being deleted until this wrapper is dropped. This is only needed to safely hand an ALooper from one thread to another.

Implementations

Source

impl AcquiredLooper

pub fn from_ref(looper: LooperRef) -> AcquiredLooper

Acquire looper to prevent its deletion until this object is dropped.