pub struct AcquiredLooper { /* private fields */ }Expand description
RAII acquired looper wrapper.
This prevents the object from being deleted until this wrapper is dropped. This is only needed to safely hand an ALooper from one thread to another.
Implementations
Sourceimpl AcquiredLooper
impl AcquiredLooper
Sourcepub fn from_ref(looper: LooperRef) -> AcquiredLooper
pub fn from_ref(looper: LooperRef) -> AcquiredLooper
Acquire looper to prevent its deletion until this object is dropped.